Package: groupedHyperframe
Type: Package
Title: Grouped Hyper Data Frame
Version: 0.4.3
Date: 2026-06-20
Description: To aggregate a hyper data frame, defined in the package 'spatstat.geom', according to a grouping structure.  To facilitate downstream analysis based on a "grouped" hyper data frame.  The author has retired from academic research. Accordingly, this package should not be considered a validated tool for use in peer-reviewed publications or as the basis for grant applications.  Backward compatibility with user-code published in <doi:10.1093/bioinformatics/btaf430> is not maintained in versions >= 0.4.0 of this package. The authors of those publications are the appropriate contacts for reproducibility inquiries. 
LazyData: true
LazyDataCompression: xz
Encoding: UTF-8
License: GPL-2
Language: en-US
Authors@R: c(person(given = 'Tingting', family =
     'Zhan', role = c('aut', 'cre'), email =
     'tingtingzhan@gmail.com', comment = c(ORCID
     = '0000-0001-9971-4844')))
URL: https://github.com/tingtingzhan/groupedHyperframe
Depends: R (>= 4.6)
Imports: cli, spatstat.geom
Suggests: survival, spatstat.data
Config/roxygen2/version: 8.0.0
Config/roxygen2/markdown: TRUE
NeedsCompilation: no
Packaged: 2026-06-18 22:19:46 UTC; tingtingzhan
Author: Tingting Zhan [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-9971-4844>)
Maintainer: Tingting Zhan <tingtingzhan@gmail.com>
Repository: CRAN
Date/Publication: 2026-06-21 15:10:02 UTC
Built: R 4.6.0; ; 2026-06-21 15:39:32 UTC; unix
