# Generated by roxygen2: do not edit by hand

S3method(aggregate,hyperframe)
S3method(aug4gam,data.frame)
S3method(aug4gam,hyperframe)
S3method(aug4gam,vectorlist)
S3method(print,vectorlist)
S3method(t,vectorlist)
export(aggregate2)
export(as.vectorlist)
export(aug4gam)
export(is.vectorlist)
export(pppBy)
import(cli)
importFrom(cli,cli_text)
importFrom(cli,col_green)
importFrom(cli,col_red)
importFrom(cli,style_bold)
importFrom(spatstat.geom,as.hyperframe.data.frame)
importFrom(spatstat.geom,cbind.hyperframe)
importFrom(spatstat.geom,names.hyperframe)
importFrom(spatstat.geom,owin)
importFrom(spatstat.geom,ppp)
importFrom(spatstat.geom,split.ppp)
importFrom(spatstat.geom,subset.hyperframe)
importFrom(stats,aggregate)
importFrom(stats,aggregate.data.frame)
importFrom(stats,model.frame.default)
importFrom(stats,setNames)
importFrom(stats,update.formula)
